InputFormatValidation mixin

A mixin that provides input format validation utilities. This includes regular expressions to restrict certain characters, such as emojis, from user input.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

emojiNoAllowRegExp ↔ RegExp
Regular expression to disallow emojis in user input.
getter/setter pair
onlyEmailAllow ↔ RegExp
Regular expression to validate an email address.
getter/setter pair
onlyNumberAllow ↔ RegExp
Regular expression to allow only numbers (digits 0-9).
getter/setter pair
onlyTextAllow ↔ RegExp
Regular expression to allow only text (alphabets a-z, A-Z).
getter/setter pair